@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -328,6 +328,25 @@ public class FormatData_iw extends ListResourceBundle {
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "\u05e9\u05e2\u05d5\u05df {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "\u200f0 \u05d0\u05dc\u05e3",
+                    "\u200f00 \u05d0\u05dc\u05e3",
+                    "\u200f000 \u05d0\u05dc\u05e3",
+                    "\u200f0 \u05de\u05d9\u05dc\u05d9\u05d5\u05df",
+                    "\u200f00 \u05de\u05d9\u05dc\u05d9\u05d5\u05df",
+                    "\u200f000 \u05de\u05d9\u05dc\u05d9\u05d5\u05df",
+                    "\u200f0 \u05de\u05d9\u05dc\u05d9\u05d0\u05e8\u05d3",
+                    "\u200f00 \u05de\u05d9\u05dc\u05d9\u05d0\u05e8\u05d3",
+                    "\u200f000 \u05de\u05d9\u05dc\u05d9\u05d0\u05e8\u05d3",
+                    "\u200f0 \u05d8\u05e8\u05d9\u05dc\u05d9\u05d5\u05df",
+                    "\u200f00 \u05d8\u05e8\u05d9\u05dc\u05d9\u05d5\u05df",
+                    "\u200f000 \u05d8\u05e8\u05d9\u05dc\u05d9\u05d5\u05df",
+                }
+            },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -397,6 +416,25 @@ public class FormatData_iw extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0K",
+                    "00K",
+                    "000K",
+                    "0M",
+                    "00M",
+                    "000M",
+                    "0B",
+                    "00B",
+                    "000B",
+                    "0T",
+                    "00T",
+                    "000T",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "\u05e9\u05e2\u05d5\u05df {0} (\u05e7\u05d9\u05e5)" },
             { "DatePatterns",
