@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -284,6 +284,25 @@ public class FormatData_te extends ListResourceBundle {
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "{0} \u0c38\u0c2e\u0c2f\u0c02" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 \u0c35\u0c47\u0c2f\u0c3f",
+                    "00 \u0c35\u0c47\u0c32\u0c41",
+                    "000 \u0c35\u0c47\u0c32\u0c41",
+                    "0 \u0c2e\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d",
+                    "00 \u0c2e\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41",
+                    "000 \u0c2e\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41",
+                    "0 \u0c2c\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d",
+                    "00 \u0c2c\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41",
+                    "000 \u0c2c\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41",
+                    "0 \u0c1f\u0c4d\u0c30\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d",
+                    "00 \u0c1f\u0c4d\u0c30\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41",
+                    "000 \u0c1f\u0c4d\u0c30\u0c3f\u0c32\u0c3f\u0c2f\u0c28\u0c4d\u0c32\u0c41",
+                }
+            },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -338,6 +357,25 @@ public class FormatData_te extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u0c35\u0c47",
+                    "00\u0c35\u0c47",
+                    "000\u0c35\u0c47",
+                    "0\u0c2e\u0c3f",
+                    "00\u0c2e\u0c3f",
+                    "000\u0c2e\u0c3f",
+                    "0\u0c2c\u0c3f",
+                    "00\u0c2c\u0c3f",
+                    "000\u0c2c\u0c3f",
+                    "0\u0c1f\u0c4d\u0c30\u0c3f",
+                    "00\u0c1f\u0c4d\u0c30\u0c3f",
+                    "000\u0c1f\u0c4d\u0c30\u0c3f",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "{0} \u0c2a\u0c17\u0c1f\u0c3f \u0c35\u0c46\u0c32\u0c41\u0c24\u0c41\u0c30\u0c41 \u0c38\u0c2e\u0c2f\u0c02" },
             { "DatePatterns",
